@@ -9,7 +9,7 @@ use Class::Utils qw(set_params);
 use PYX::Parser;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -196,13 +196,13 @@ L<PYX::Parser>.
 
 =head1 SEE ALSO
 
-L<PYX>,
-L<PYX::GraphViz>,
-L<PYX::Hist>,
-L<PYX::Parser>,
-L<PYX::Stack>,
-L<PYX::Utils>,
-L<Task::PYX>.
+=over
+
+=item L<Task::PYX>
+
+Install the PYX modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -221,6 +221,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
